##  Implementation Details
SAP LeanIX uses the Okta SDK for Go version 2 to interact with Okta's Core API. This SDK allows SAP LeanIX to manage various Okta resources, such as users, groups, and applications. To learn more about Okta SDK, see [Okta SDK Golang![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fgithub.com%2Fokta%2Fokta-sdk-golang "https://github.com/okta/okta-sdk-golang").
API reference: The SDK leverages endpoints provided by Okta's Core API. You can find detailed information about these endpoints, including request and response formats, in their documentation [Okta Core API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.okta.com%2Fdocs%2Freference%2Fcore-okta-api%2F "https://developer.okta.com/docs/reference/core-okta-api/").
Rate limits: To ensure smooth operation and avoid disruptions, be mindful of the rate limits imposed by Okta's API. The specific rate limits for different operations are detailed in their documentation [Okta API Rate Limits![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.okta.com%2Fdocs%2Freference%2Frate-limits%2F "https://developer.okta.com/docs/reference/rate-limits/").
Listing Applications: A common use case is listing all applications within an Okta organization. You can find the relevant endpoint for this operation in their documentation [Applications API![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.okta.com%2Fdocs%2Freference%2Fapi%2Fapps%2F%23list-applications "https://developer.okta.com/docs/reference/api/apps/#list-applications").
To cross-check the discovered services, go to the Okta administrator console and select Applications under the Applications section on the left-side pane.
Integration Categories | Authentication Mechanism | API Endpoints Used | Okta Resource
---|---|---|---
Single Sign-On Systems (SSO) | API - OAuth |  For API authentication: /oauth2/v1/token For SaaS discovery: /api/v1/apps |  [Apps![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fdeveloper.okta.com%2Fdocs%2Freference%2Fapi%2Fapps%2F "https://developer.okta.com/docs/reference/api/apps/")


